-- BNDs nvim config <3
-- -------------------

vim.cmd("set expandtab")
vim.cmd("set tabstop=4")
vim.cmd("set softtabstop=4")
vim.cmd("set shiftwidth=4")
vim.g.mapleader=" "

-- import lazy package manager
require("config.lazy")

-- Set the color scheme
vim.cmd.colorscheme "habamax"

-- line numbers 
vim.o.number = true        -- Enable line numbers
vim.o.relativenumber = true -- Enable relative line numbers
vim.cmd [[
  autocmd InsertEnter * set norelativenumber " Disable relative numbers in insert mode
  autocmd InsertLeave * set relativenumber  " Enable relative numbers in normal mode
]]

-- Telescope
local builtin = require("telescope.builtin")
vim.keymap.set('n', '<leader>p', builtin.find_files, {})
vim.keymap.set('n', '<leader>fg', builtin.live_grep, {})

-- Treesitter
local config = require("nvim-treesitter.configs")
config.setup({
    ensure_installed = {"lua", "javascript"},
    sync_install = false,
    highlight = { enable = true },
    indent = { enable = true },
})

-- Neotree
vim.keymap.set('n', '<leader>o', ':Neotree filesystem reveal right<CR>', {})

vim.keymap.set('i', '<C-Space>', '<ESC>', { noremap = true })
vim.keymap.set('n', 'o', 'a', { noremap = true })
vim.keymap.set('n', 'u', 'i', { noremap = true })
vim.keymap.set('n', 'O', 'o', { noremap = true })
vim.keymap.set('n', 'U', 'O', { noremap = true })
vim.keymap.set('n', 'xx', 'dd', { noremap = true })
vim.keymap.set('n', 'cc', 'yy', { noremap = true })

for _,mode in pairs({'n', 'x', 'o'}) do
    vim.keymap.set(mode, 'j', 'h', { noremap = true })
    vim.keymap.set(mode, 'k', 'j', { noremap = true })
    vim.keymap.set(mode, 'i', 'k', { noremap = true })

    vim.keymap.set(mode, 'J', '0', { noremap = true })
    vim.keymap.set(mode, 'L', '$', { noremap = true })
    vim.keymap.set(mode, 'I', 'H', { noremap = true })
    vim.keymap.set(mode, 'K', 'L', { noremap = true })

    vim.keymap.set(mode, '<C-l>', 'w', { noremap = true })
    vim.keymap.set(mode, '<C-j>', 'b', { noremap = true })
    vim.keymap.set(mode, '<C-i>', '<C-b>', { noremap = true })
    vim.keymap.set(mode, '<C-k>', '<C-f>', { noremap = true })

    vim.keymap.set(mode, 'c', 'y', { noremap = true })
    vim.keymap.set(mode, 'y', 'v', { noremap = true })
    vim.keymap.set(mode, 'x', 'd', { noremap = true })
    vim.keymap.set(mode, 'v', 'p', { noremap = true })
    vim.keymap.set(mode, 'h', 'c', { noremap = true })
end

vim.keymap.set('n', 'z', ':undo<cr>', { noremap = true })
vim.keymap.set('n', 'Z', ':redo<cr>', { noremap = true })
vim.keymap.set('n', 's', ':w<cr>', { noremap = true })
vim.keymap.set('n', '<C-q>', ':xa<cr>', { noremap = true })

vim.keymap.set('n', 'S', ':source %<cr>', { noremap = true })

