vim.cmd("set expandtab")
vim.cmd("set tabstop=4")
vim.cmd("set softtabstop=4")
vim.cmd("set shiftwidth=4")
vim.g.mapleader = " "

-- Initialize vim-plug
----------------------
local plug_path = vim.fn.stdpath('data') .. '/site/autoload/plug.vim'
if vim.fn.empty(vim.fn.glob(plug_path)) > 0 then
  vim.fn.system({
    'sh', '-c',
    'curl -fLo ' .. plug_path .. ' --create-dirs ' ..
    'https://raw.githubusercontent.com/junegunn/vim-plug/master/plug.vim'
  })
  vim.cmd 'autocmd VimEnter * PlugInstall | source $MYVIMRC'
end


-- vim-plug Plugin Section
--------------------------
vim.cmd [[
call plug#begin('~/.config/nvim/plugged')

Plug 'nvim-treesitter/nvim-treesitter', {'do': ':TSUpdate'}
Plug 'neovim/nvim-lspconfig'
Plug 'ellisonleao/gruvbox.nvim'
Plug 'nvim-lua/plenary.nvim'

Plug 'nvim-telescope/telescope.nvim', { 'tag': '0.1.8' }
Plug 'nvim-telescope/telescope-ui-select.nvim'

Plug 'https://github.com/nvim-neo-tree/neo-tree.nvim.git'
Plug 'nvim-tree/nvim-web-devicons'
Plug 'MunifTanjim/nui.nvim'
Plug 'nvim-lualine/lualine.nvim'

Plug 'williamboman/mason.nvim'
Plug 'williamboman/mason-lspconfig.nvim'
Plug 'neovim/nvim-lspconfig'

call plug#end()
]]

-- line numbers 
---------------
vim.o.number = true        -- Enable line numbers
vim.o.relativenumber = true -- Enable relative line numbers
vim.cmd [[
  autocmd InsertEnter * set norelativenumber " Disable relative numbers in insert mode
  autocmd InsertLeave * set relativenumber  " Enable relative numbers in normal mode
]]

-- Set colorscheme
------------------
vim.o.background = "dark" -- or "light" for light mode
-- Default options:
require("gruvbox").setup({
  terminal_colors = true, -- add neovim terminal colors
  contrast = "soft", -- can be "hard", "soft" or empty string
  palette_overrides = {
--    bright_green = "#ffffff",
  }
})
vim.cmd("colorscheme gruvbox")

-- Set up Telescope
-------------------
local builtin = require("telescope.builtin")
vim.keymap.set('n', '<C-p>', builtin.find_files, {})
vim.keymap.set('n', '<leader>ff', builtin.find_files, {})
vim.keymap.set('n', '<leader>fg', builtin.live_grep, {}) 

-- This is your opts table
require("telescope").setup {
  extensions = {
    ["ui-select"] = {
      require("telescope.themes").get_dropdown {
        -- even more opts
      }
    }
  }
}
-- To get ui-select loaded and working with telescope, you need to call
-- load_extension, somewhere after setup function:
require("telescope").load_extension("ui-select")

-- Treesitter
-------------
local config = require("nvim-treesitter.configs")
config.setup({
    ensure_installed = {"lua", "javascript", "rust", "json"},
    highlight = { enable = true },
    indent = { enable = true },
})

-- Neotree
----------
vim.keymap.set('n', '<C-n>', ':Neotree filesystem reveal left<CR>')

-- Status line
--------------
require('lualine').setup()

-- LSP configuration
--------------------
require('mason').setup()
require('mason-lspconfig').setup({
    ensure_installed = { "lua_ls", "ts_ls" }
})

local lspconfig = require('lspconfig')
lspconfig.lua_ls.setup({})
lspconfig.ts_ls.setup({})
vim.keymap.set('n', 'K', vim.lsp.buf.hover, {})
vim.keymap.set('n', '<leader>ca', vim.lsp.buf.code_action, {})
