#!/bin/bash

connect_known_wifi() {
    KNOWN_WIFIS=$(nmcli connection show --active | awk 'NR>1 {print $1}')
    if [[ -z "$KNOWN_WIFIS" ]]; then
        notify-send "No known WiFi networks found"
        return
    fi
    SELECTED=$(echo -e "$KNOWN_WIFIS" | rofi -dmenu -p "Known WiFi:")
    if [[ -n "$SELECTED" ]]; then
        nmcli connection up "$SELECTED" && notify-send "Connected to $SELECTED" || notify-send "Failed to connect to $SELECTED"
    fi
}

# Function to scan for WiFi networks and connect
scan_wifi() {
    SCANNED_WIFIS=$(nmcli -f SSID,BARS device wifi list | awk 'NR>1')
    if [[ -z "$SCANNED_WIFIS" ]]; then
        notify-send "No WiFi networks found"
        return
    fi
    SELECTED=$(echo -e "$SCANNED_WIFIS" | rofi -dmenu -p "Available WiFi:")
    if [[ -n "$SELECTED" ]]; then
        PASSWORD=$(rofi -dmenu -p "Password for $SELECTED (leave blank if none):")
        nmcli device wifi connect "$SELECTED" password "$PASSWORD" && notify-send "Connected to $SELECTED" || notify-send "Failed to connect to $SELECTED"
    fi
}

WIFI_STATE=$(nmcli radio wifi)
if [[ "$WIFI_STATE" == "enabled" ]]; then
    OPTIONS="Disable WiFi\n"
    CURRENT_NETWORK=$(nmcli connection show --active | grep 'wlan0' | awk 'NR {print $1}')
    if [[ "$CURRENT_NETWORK" != "" ]]; then
        OPTIONS="${OPTIONS}Disconnect $CURRENT_NETWORK\n"
    fi
else
    OPTIONS="Enable WiFi\n"
fi

OPTIONS="${OPTIONS}Connect to known WiFi\nScan for WiFi\nEdit connections"

CHOICE=$(echo -e $OPTIONS | rofi -dmenu -p "Wifi manager")

case "$CHOICE" in
    "Enable WiFi")
        nmcli radio wifi on && notify-send "WiFi enabled"
        ;;
    "Disable WiFi")
        nmcli radio wifi off && notify-send "WiFi disabled"
        ;;
    "Connect to known WiFi")
        connect_known_wifi
        ;;
    "Scan for WiFi")
        scan_wifi
        ;;
    "Edit connections")
        nm-connection-editor &
        ;;
    "Disconnect $CURRENT_NETWORK")
        nmcli connection down id $CURRENT_NETWORK &
        ;;
    *)
        notify-send "Invalid choice or canceled"
        ;;
esac

